@@ -19,4 +19,6 @@ print( estResultRay )
 summary( estResultRay )
 efficiencies( estResultRay )
 efficiencies( estResultRay, asInData = TRUE )
+residuals( estResultRay )
+residuals( estResultRay, asInData = TRUE )
 print.default( estResultRay )
